
local painter = {}
painter.tiles = {}

painter.rgb = {
  {r=64,g=64,b=64,color={255,255,255},name="wall",img=quads.wall,collide=true},
  {r=0,g=148,b=255,color={0,127,14},name="spawn",img=quads.brush2,collide=false},
  {r=255,g=0,b=0,color={0,127,14},name="brush",img=quads.brush1,collide=false},
  {r=0,g=74,b=127,color={0,74,127},name="water",img=quads.water,collide=true}
}

function painter.convert(img)
  local pixelData = {}
  local img = love.image.newImageData(img)
  for x=1, img:getWidth() do
    for y=1, img:getHeight() do
      local pixel = {}
      pixel.r, pixel.g, pixel.b = img:getPixel(x-1, y-1)
      pixel.x, pixel.y = x, y
      table.insert(pixelData, pixel)
    end
  end
  return pixelData
end

function painter.tile(data)
  for k, tile in ipairs(data) do
    for v, color in ipairs(painter.rgb) do
      if tile.r == color.r and tile.g == color.g and tile.b == color.b then
        local brushR = love.math.random(1, 3)
        local img = color.img
        if color.name == "brush" then img = quads["brush" .. brushR] end
        local newtile = {
          r=tile.r,g=tile.g,b=tile.b,color=color.color,
          x=tile.x*tilesize,y=tile.y*tilesize,img=img,
          w=tilesize,h=tilesize,name=color.name,collide=color.collide}
        if color.name == "spawn" then player.spawn(tile.x*tilesize,tile.y*tilesize) end
        table.insert(painter.tiles, newtile)
        world:add(newtile, newtile.x, newtile.y, newtile.w, newtile.h)
      end
    end
  end
end

function painter.paint()
  for k, v in ipairs(painter.tiles) do
    love.graphics.setColor(v.color)
    if v.img then
      love.graphics.draw(atlas, v.img, v.x, v.y, 0, 1)
    end
  end
end

function painter.debug()
  for k, v in ipairs(painter.tiles) do
    print("x " .. v.x/tilesize .. " y " .. v.y/tilesize .. " n " .. v.name)
  end
end

return painter
